Sophie

Sophie

distrib > Scientific%20Linux > 5x > x86_64 > by-pkgid > eb8ea93c0f34821251df6d6c349b7466 > files > 9

e4fsprogs-1.41.1-2.el5.src.rpm

Index: e2fsprogs-1.41.1/misc/dumpe2fs.c
===================================================================
--- e2fsprogs-1.41.1.orig/misc/dumpe2fs.c	2008-08-28 09:26:31.000000000 -0500
+++ e2fsprogs-1.41.1/misc/dumpe2fs.c	2008-09-12 13:29:48.356141285 -0500
@@ -44,7 +44,7 @@ extern int optind;
 
 #define in_use(m, x)	(ext2fs_test_bit ((x), (m)))
 
-const char * program_name = "dumpe2fs";
+const char * program_name = "dumpe4fs";
 char * device_name = NULL;
 int hex_format = 0;
 
@@ -443,7 +443,7 @@ int main (int argc, char ** argv)
 	textdomain(NLS_CAT_NAME);
 #endif
 	add_error_table(&et_ext2_error_table);
-	fprintf (stderr, "dumpe2fs %s (%s)\n", E2FSPROGS_VERSION,
+	fprintf (stderr, "dumpe4fs %s (%s)\n", E2FSPROGS_VERSION,
 		 E2FSPROGS_DATE);
 	if (argc && *argv)
 		program_name = *argv;
Index: e2fsprogs-1.41.1/misc/e2image.c
===================================================================
--- e2fsprogs-1.41.1.orig/misc/e2image.c	2008-09-01 10:36:38.000000000 -0500
+++ e2fsprogs-1.41.1/misc/e2image.c	2008-09-12 13:29:48.357140276 -0500
@@ -44,7 +44,7 @@ extern int optind;
 #include "../version.h"
 #include "nls-enable.h"
 
-const char * program_name = "e2image";
+const char * program_name = "e4image";
 char * device_name = NULL;
 
 static void usage(void)
@@ -637,7 +637,7 @@ int main (int argc, char ** argv)
 	bindtextdomain(NLS_CAT_NAME, LOCALEDIR);
 	textdomain(NLS_CAT_NAME);
 #endif
-	fprintf (stderr, "e2image %s (%s)\n", E2FSPROGS_VERSION,
+	fprintf (stderr, "e4image %s (%s)\n", E2FSPROGS_VERSION,
 		 E2FSPROGS_DATE);
 	if (argc && *argv)
 		program_name = *argv;
Index: e2fsprogs-1.41.1/misc/tune2fs.c
===================================================================
--- e2fsprogs-1.41.1.orig/misc/tune2fs.c	2008-09-01 10:36:09.000000000 -0500
+++ e2fsprogs-1.41.1/misc/tune2fs.c	2008-09-12 13:29:48.399077180 -0500
@@ -59,7 +59,7 @@ extern int optind;
 #include "../version.h"
 #include "nls-enable.h"
 
-const char * program_name = "tune2fs";
+const char * program_name = "tune4fs";
 char * device_name;
 char * new_label, *new_last_mounted, *new_UUID;
 char * io_options;
@@ -93,7 +93,7 @@ struct blk_move {
 };
 
 
-static const char *please_fsck = N_("Please run e2fsck on the filesystem.\n");
+static const char *please_fsck = N_("Please run e4fsck on the filesystem.\n");
 
 void do_findfs(int argc, char **argv);
 
@@ -377,7 +377,7 @@ static void update_feature_set(ext2_fils
 		if (sb->s_feature_incompat &
 		    EXT3_FEATURE_INCOMPAT_RECOVER) {
 			fputs(_("The needs_recovery flag is set.  "
-				"Please run e2fsck before clearing\n"
+				"Please run e4fsck before clearing\n"
 				"the has_journal flag.\n"), stderr);
 			exit(1);
 		}
@@ -538,7 +538,7 @@ err:
 static void parse_e2label_options(int argc, char ** argv)
 {
 	if ((argc < 2) || (argc > 3)) {
-		fputs(_("Usage: e2label device [newlabel]\n"), stderr);
+		fputs(_("Usage: e4label device [newlabel]\n"), stderr);
 		exit(1);
 	}
 	io_options = strchr(argv[1], '?');
@@ -546,7 +546,7 @@ static void parse_e2label_options(int ar
 		*io_options++ = 0;
 	device_name = blkid_get_devname(NULL, argv[1], NULL);
 	if (!device_name) {
-		com_err("e2label", 0, _("Unable to resolve '%s'"),
+		com_err("e4label", 0, _("Unable to resolve '%s'"),
 			argv[1]);
 		exit(1);
 	}
@@ -598,7 +598,7 @@ static void parse_tune2fs_options(int ar
 
 	open_flag = 0;
 
-	printf("tune2fs %s (%s)\n", E2FSPROGS_VERSION, E2FSPROGS_DATE);
+	printf("tune4fs %s (%s)\n", E2FSPROGS_VERSION, E2FSPROGS_DATE);
 	while ((c = getopt(argc, argv, "c:e:fg:i:jlm:o:r:s:u:C:E:I:J:L:M:O:T:U:")) != EOF)
 		switch (c)
 		{
@@ -831,7 +831,7 @@ static void parse_tune2fs_options(int ar
 		*io_options++ = 0;
 	device_name = blkid_get_devname(NULL, argv[optind], NULL);
 	if (!device_name) {
-		com_err("tune2fs", 0, _("Unable to resolve '%s'"),
+		com_err("tune4fs", 0, _("Unable to resolve '%s'"),
 			argv[optind]);
 		exit(1);
 	}
@@ -843,12 +843,12 @@ void do_findfs(int argc, char **argv)
 
 	if ((argc != 2) ||
 	    (strncmp(argv[1], "LABEL=", 6) && strncmp(argv[1], "UUID=", 5))) {
-		fprintf(stderr, "Usage: findfs LABEL=<label>|UUID=<uuid>\n");
+		fprintf(stderr, "Usage: finde4fs LABEL=<label>|UUID=<uuid>\n");
 		exit(2);
 	}
 	dev = blkid_get_devname(NULL, argv[1], NULL);
 	if (!dev) {
-		com_err("findfs", 0, _("Unable to resolve '%s'"),
+		com_err("finde4fs", 0, _("Unable to resolve '%s'"),
 			argv[1]);
 		exit(1);
 	}
@@ -1393,7 +1393,7 @@ static int tune2fs_setup_tdb(const char 
 	    access(tdb_dir, W_OK))
 		return 0;
 
-	sprintf(tdb_file, "%s/tune2fs-%s.e2undo", tdb_dir, dev_name);
+	sprintf(tdb_file, "%s/tune4fs-%s.e4undo", tdb_dir, dev_name);
 
 	if (!access(tdb_file, F_OK)) {
 		if (unlink(tdb_file) < 0) {
@@ -1408,8 +1408,8 @@ static int tune2fs_setup_tdb(const char 
 	set_undo_io_backing_manager(*io_ptr);
 	*io_ptr = undo_io_manager;
 	set_undo_io_backup_file(tdb_file);
-	printf(_("To undo the tune2fs operations please run "
-		 "the command\n    e2undo %s %s\n\n"),
+	printf(_("To undo the tune4fs operations please run "
+		 "the command\n    e4undo %s %s\n\n"),
 		 tdb_file, name);
 	free(tmp_name);
 	return retval;
@@ -1432,9 +1432,9 @@ int main (int argc, char ** argv)
 		program_name = *argv;
 	add_error_table(&et_ext2_error_table);
 
-	if (strcmp(get_progname(argv[0]), "findfs") == 0)
+	if (strcmp(get_progname(argv[0]), "finde4fs") == 0)
 		do_findfs(argc, argv);
-	if (strcmp(get_progname(argv[0]), "e2label") == 0)
+	if (strcmp(get_progname(argv[0]), "e4label") == 0)
 		parse_e2label_options(argc, argv);
 	else
 		parse_tune2fs_options(argc, argv);
@@ -1637,7 +1637,7 @@ retry_open:
 		fs->flags &= ~EXT2_FLAG_SUPER_ONLY;
 		if (resize_inode(fs, new_inode_size)) {
 			fputs(_("Error in resizing the inode size.\n"
-				"Run e2undo to undo the "
+				"Run e4undo to undo the "
 				"file system changes. \n"), stderr);
 		} else {
 			printf (_("Setting inode size %lu\n"),
Index: e2fsprogs-1.41.1/resize/main.c
===================================================================
--- e2fsprogs-1.41.1.orig/resize/main.c	2008-09-01 10:36:16.000000000 -0500
+++ e2fsprogs-1.41.1/resize/main.c	2008-09-12 13:29:48.415393711 -0500
@@ -183,7 +183,7 @@ int main (int argc, char ** argv)
 
 	add_error_table(&et_ext2_error_table);
 
-	fprintf (stderr, "resize2fs %s (%s)\n",
+	fprintf (stderr, "resize4fs %s (%s)\n",
 		 E2FSPROGS_VERSION, E2FSPROGS_DATE);
 	if (argc && *argv)
 		program_name = *argv;
@@ -336,7 +336,7 @@ int main (int argc, char ** argv)
 	    !(fs->super->s_feature_compat & EXT2_FEATURE_COMPAT_RESIZE_INODE)) {
 		com_err(program_name, 0, _("%s: The combination of flex_bg "
 					   "and\n\t!resize_inode features "
-					   "is not supported by resize2fs.\n"),
+					   "is not supported by resize4fs.\n"),
 			device_name);
 		exit(1);
 	}
Index: e2fsprogs-1.41.1/e2fsck/unix.c
===================================================================
--- e2fsprogs-1.41.1.orig/e2fsck/unix.c	2008-09-01 10:34:28.000000000 -0500
+++ e2fsprogs-1.41.1/e2fsck/unix.c	2008-09-12 13:29:48.432086062 -0500
@@ -216,7 +216,7 @@ static void check_mount(e2fsck_t ctx)
 	if (!ctx->interactive)
 		fatal_error(ctx, _("Cannot continue, aborting.\n\n"));
 	printf(_("\n\n\007\007\007\007WARNING!!!  "
-	       "Running e2fsck on a mounted filesystem may cause\n"
+	       "Running e4fsck on a mounted filesystem may cause\n"
 	       "SEVERE filesystem damage.\007\007\007\n\n"));
 	cont = ask_yn(_("Do you really want to continue"), -1);
 	if (!cont) {
@@ -595,12 +595,12 @@ static void parse_extended_opts(e2fsck_t
 static void syntax_err_report(const char *filename, long err, int line_num)
 {
 	fprintf(stderr,
-		_("Syntax error in e2fsck config file (%s, line #%d)\n\t%s\n"),
+		_("Syntax error in e4fsck config file (%s, line #%d)\n\t%s\n"),
 		filename, line_num, error_message(err));
 	exit(FSCK_ERROR);
 }
 
-static const char *config_fn[] = { ROOT_SYSCONFDIR "/e2fsck.conf", 0 };
+static const char *config_fn[] = { ROOT_SYSCONFDIR "/e4fsck.conf", 0 };
 
 static errcode_t PRS(int argc, char *argv[], e2fsck_t *ret_ctx)
 {
@@ -644,7 +644,7 @@ static errcode_t PRS(int argc, char *arg
 	if (argc && *argv)
 		ctx->program_name = *argv;
 	else
-		ctx->program_name = "e2fsck";
+		ctx->program_name = "e4fsck";
 	while ((c = getopt (argc, argv, "panyrcC:B:dE:fvtFVM:b:I:j:P:l:L:N:SsDk")) != EOF)
 		switch (c) {
 		case 'C':
@@ -704,7 +704,7 @@ static errcode_t PRS(int argc, char *arg
 				ctx->options |= E2F_OPT_TIME;
 #else
 			fprintf(stderr, _("The -t option is not "
-				"supported on this version of e2fsck.\n"));
+				"supported on this version of e4fsck.\n"));
 #endif
 			break;
 		case 'c':
@@ -919,7 +919,7 @@ int main (int argc, char *argv[])
 
 	retval = PRS(argc, argv, &ctx);
 	if (retval) {
-		com_err("e2fsck", retval,
+		com_err("e4fsck", retval,
 			_("while trying to initialize program"));
 		exit(FSCK_ERROR);
 	}
@@ -930,7 +930,7 @@ int main (int argc, char *argv[])
 #endif
 
 	if (!(ctx->options & E2F_OPT_PREEN) || show_version_only)
-		fprintf(stderr, "e2fsck %s (%s)\n", my_ver_string,
+		fprintf(stderr, "e4fsck %s (%s)\n", my_ver_string,
 			 my_ver_date);
 
 	if (show_version_only) {
@@ -1022,7 +1022,7 @@ restart:
 			ctx->filesystem_name);
 		if (retval == EXT2_ET_REV_TOO_HIGH) {
 			printf(_("The filesystem revision is apparently "
-			       "too high for this version of e2fsck.\n"
+			       "too high for this version of e4fsck.\n"
 			       "(Or the filesystem superblock "
 			       "is corrupt)\n\n"));
 			fix_problem(ctx, PR_0_SB_CORRUPT, &pctx);
@@ -1104,7 +1104,7 @@ restart:
 			_("while trying to open %s"),
 			ctx->filesystem_name);
 	get_newer:
-		fatal_error(ctx, _("Get a newer version of e2fsck!"));
+		fatal_error(ctx, _("Get a newer version of e4fsck!"));
 	}
 
 	/*
@@ -1306,7 +1306,7 @@ print_unsupp_features:
 no_journal:
 
 	if (run_result == E2F_FLAG_RESTART) {
-		printf(_("Restarting e2fsck from the beginning...\n"));
+		printf(_("Restarting e4fsck from the beginning...\n"));
 		retval = e2fsck_reset_context(ctx);
 		if (retval) {
 			com_err(ctx->program_name, retval,
@@ -1317,7 +1317,7 @@ no_journal:
 		goto restart;
 	}
 	if (run_result & E2F_FLAG_CANCEL) {
-		printf(_("%s: e2fsck canceled.\n"), ctx->device_name ?
+		printf(_("%s: e4fsck canceled.\n"), ctx->device_name ?
 		       ctx->device_name : ctx->filesystem_name);
 		exit_value |= FSCK_CANCELED;
 	}
Index: e2fsprogs-1.41.1/debugfs/debugfs.c
===================================================================
--- e2fsprogs-1.41.1.orig/debugfs/debugfs.c	2008-08-28 09:26:31.000000000 -0500
+++ e2fsprogs-1.41.1/debugfs/debugfs.c	2008-09-12 13:29:48.449077223 -0500
@@ -1931,7 +1931,7 @@ int main(int argc, char **argv)
 	char		*data_filename = 0;
 
 	if (debug_prog_name == 0)
-		debug_prog_name = "debugfs";
+		debug_prog_name = "debuge4fs";
 
 	add_error_table(&et_ext2_error_table);
 	fprintf (stderr, "%s %s (%s)\n", debug_prog_name,
Index: e2fsprogs-1.41.1/tests/f_illitable/expect.1
===================================================================
--- e2fsprogs-1.41.1.orig/tests/f_illitable/expect.1	2007-06-30 07:58:36.000000000 -0500
+++ e2fsprogs-1.41.1/tests/f_illitable/expect.1	2008-09-12 13:29:48.465571831 -0500
@@ -12,7 +12,7 @@ Relocate? yes
 This doesn't bode well, but we'll try to go on...
 Pass 1: Checking inodes, blocks, and sizes
 Relocating group 0's inode table to 5...
-Restarting e2fsck from the beginning...
+Restarting e4fsck from the beginning...
 Pass 1: Checking inodes, blocks, and sizes
 Root inode is not a directory.  Clear? yes
 
Index: e2fsprogs-1.41.1/tests/f_lotsbad/expect.1
===================================================================
--- e2fsprogs-1.41.1.orig/tests/f_lotsbad/expect.1	2008-04-02 10:56:12.000000000 -0500
+++ e2fsprogs-1.41.1/tests/f_lotsbad/expect.1	2008-09-12 13:29:48.482263430 -0500
@@ -24,7 +24,7 @@ Illegal block #22 (543512352) in inode 1
 Too many illegal blocks in inode 12.
 Clear inode? yes
 
-Restarting e2fsck from the beginning...
+Restarting e4fsck from the beginning...
 Pass 1: Checking inodes, blocks, and sizes
 Pass 2: Checking directory structure
 Entry 'termcap' in / (2) has deleted/unused inode 12.  Clear? yes
Index: e2fsprogs-1.41.1/tests/f_misstable/expect.1
===================================================================
--- e2fsprogs-1.41.1.orig/tests/f_misstable/expect.1	2007-10-15 09:22:26.000000000 -0500
+++ e2fsprogs-1.41.1/tests/f_misstable/expect.1	2008-09-12 13:29:48.499077399 -0500
@@ -5,7 +5,7 @@ Relocate? yes
 
 Pass 1: Checking inodes, blocks, and sizes
 Relocating group 1's inode table to 8197...
-Restarting e2fsck from the beginning...
+Restarting e4fsck from the beginning...
 Pass 1: Checking inodes, blocks, and sizes
 Pass 2: Checking directory structure
 Entry 'etc' in / (2) has deleted/unused inode 1505.  Clear? yes
Index: e2fsprogs-1.41.1/tests/u_mke2fs/script
===================================================================
--- e2fsprogs-1.41.1.orig/tests/u_mke2fs/script	2008-08-24 23:19:56.000000000 -0500
+++ e2fsprogs-1.41.1/tests/u_mke2fs/script	2008-09-12 13:30:33.001077206 -0500
@@ -3,7 +3,7 @@ if test -x $E2UNDO_EXE; then
 
 E2FSPROGS_UNDO_DIR=./
 export E2FSPROGS_UNDO_DIR
-TDB_FILE=./mke2fs-test.img.e2undo
+TDB_FILE=./mke4fs-test.img.e4undo
 OUT=$test_name.log
 rm -f $TDB_FILE >/dev/null 2>&1
 
Index: e2fsprogs-1.41.1/tests/u_tune2fs/script
===================================================================
--- e2fsprogs-1.41.1.orig/tests/u_tune2fs/script	2008-08-24 23:19:56.000000000 -0500
+++ e2fsprogs-1.41.1/tests/u_tune2fs/script	2008-09-12 13:30:41.701077356 -0500
@@ -3,7 +3,7 @@ if test -x $E2UNDO_EXE; then
 
 E2FSPROGS_UNDO_DIR=./
 export E2FSPROGS_UNDO_DIR
-TDB_FILE=./tune2fs-test.img.e2undo
+TDB_FILE=./tune4fs-test.img.e4undo
 OUT=$test_name.log
 rm -f $TDB_FILE >/dev/null 2>&1
Index: e2fsprogs-1.41.1/misc/mke2fs.c
===================================================================
--- e2fsprogs-1.41.1.orig/misc/mke2fs.c	2008-09-01 10:34:07.000000000 -0500
+++ e2fsprogs-1.41.1/misc/mke2fs.c	2008-09-12 13:29:48.382077016 -0500
@@ -69,7 +69,7 @@ extern int optind;
 extern int isatty(int);
 extern FILE *fpopen(const char *cmd, const char *mode);
 
-const char * program_name = "mke2fs";
+const char * program_name = "mke4fs";
 const char * device_name /* = NULL */;
 
 /* Command line options */
@@ -852,12 +852,12 @@ static __u32 ok_features[3] = {
 static void syntax_err_report(const char *filename, long err, int line_num)
 {
 	fprintf(stderr,
-		_("Syntax error in mke2fs config file (%s, line #%d)\n\t%s\n"),
+		_("Syntax error in mke4fs config file (%s, line #%d)\n\t%s\n"),
 		filename, line_num, error_message(err));
 	exit(1);
 }
 
-static const char *config_fn[] = { ROOT_SYSCONFDIR "/mke2fs.conf", 0 };
+static const char *config_fn[] = { ROOT_SYSCONFDIR "/mke4fs.conf", 0 };
 
 static void edit_feature(const char *str, __u32 *compat_array)
 {
@@ -973,11 +973,11 @@ static char **parse_fs_type(const char *
 		profile_get_string(profile, "fs_types", ext_type, "features",
 				   0, &t);
 		if (!t) {
-			printf(_("\nWarning!  Your mke2fs.conf file does "
+			printf(_("\nWarning!  Your mke4fs.conf file does "
 				 "not define the %s filesystem type.\n"),
 			       ext_type);
 			printf(_("You probably need to install an updated "
-				 "mke2fs.conf file.\n\n"));
+				 "mke4fs.conf file.\n\n"));
 			sleep(5);
 		}
 	}
@@ -1156,9 +1156,13 @@ static void PRS(int argc, char *argv[])
 	if (argc && *argv) {
 		program_name = get_progname(*argv);
 
-		/* If called as mkfs.ext3, create a journal inode */
-		if (!strcmp(program_name, "mkfs.ext3"))
+		/* If called as mkfs.ext3 or mkfs.ext4*, create a journal inode */
+		if (!strcmp(program_name, "mkfs.ext3") || !strncmp(program_name, "mkfs.ext4", 9))
 			journal_size = -1;
+
+		/* if called as mkfs.ext4dev, set test_fs */
+		if (!strcmp(program_name, "mkfs.ext4dev"))
+			fs_param.s_flags |= EXT2_FLAGS_TEST_FILESYS;
 	}
 
 	while ((c = getopt (argc, argv,
@@ -1341,7 +1345,7 @@ static void PRS(int argc, char *argv[])
 	device_name = argv[optind++];
 
 	if (!quiet || show_version_only)
-		fprintf (stderr, "mke2fs %s (%s)\n", E2FSPROGS_VERSION,
+		fprintf (stderr, "mke4fs %s (%s)\n", E2FSPROGS_VERSION,
 			 E2FSPROGS_DATE);
 
 	if (show_version_only) {
@@ -1516,7 +1520,7 @@ static void PRS(int argc, char *argv[])
 	}
 
 	if (verbose) {
-		fputs(_("fs_types for mke2fs.conf resolution: "), stdout);
+		fputs(_("fs_types for mke4fs.conf resolution: "), stdout);
 		print_str_list(fs_types);
 	}
 
@@ -1796,7 +1800,7 @@ static int mke2fs_setup_tdb(const char *
 
 	tmp_name = strdup(name);
 	device_name = basename(tmp_name);
-	sprintf(tdb_file, "%s/mke2fs-%s.e2undo", tdb_dir, device_name);
+	sprintf(tdb_file, "%s/mke4fs-%s.e4undo", tdb_dir, device_name);
 
 	if (!access(tdb_file, F_OK)) {
 		if (unlink(tdb_file) < 0) {